@@ -1,7 +1,12 @@
 # Copyright (c) 2010 Noah Kantrowitz <noah@coderanger.net>
+
+__version__ = (0, 2, 0)
+
 from chef.api import ChefAPI, autoconfigure
+from chef.client import Client
 from chef.data_bag import DataBag, DataBagItem
 from chef.exceptions import ChefError
 from chef.node import Node
 from chef.role import Role
+from chef.environment import Environment
 from chef.search import Search
